import numpy as np
import matplotlib.pyplot as plt
from scipy.spatial import Voronoi, voronoi_plot_2d

# 设置随机种子以便重复实验
np.random.seed(42)

# 生成随机交通点
num_points = 300
x_coords = np.random.uniform(115.5, 117.5, num_points)
y_coords = np.random.uniform(39.5, 40.0, num_points)

# 合并成坐标数组
points = np.vstack((x_coords, y_coords)).T

# 计算Voronoi图
vor = Voronoi(points)

# 创建绘图
fig, ax = plt.subplots(figsize=(10, 10))

# 绘制Voronoi图
voronoi_plot_2d(vor, ax=ax, show_vertices=False, line_colors='orange', fill=False)

# 绘制交通点
ax.plot(points[:, 0], points[:, 1], 'o', color='blue')

# 设置图形标题和标签
ax.set_title('Voronoi Diagram of Traffic Flow in Beijing')
ax.set_xlabel('Longitude')
ax.set_ylabel('Latitude')
ax.set_xlim(115.5, 117.5)
ax.set_ylim(39.5, 40.0)

plt.savefig('beijing_voronoi_diagram.png', dpi=300, bbox_inches='tight')

# 显示图形
plt.grid()
plt.show()
